# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import data_search_pb2 as data__search__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in data_search_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DataSearchApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_schema = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_schema',
                request_serializer=data__search__pb2.DataSearchSchemaGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchSchemaGetResponse.FromString,
                _registered_method=True)
        self.search = channel.unary_unary(
                '/oi.papi.DataSearchApi/search',
                request_serializer=data__search__pb2.DataSearchRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchResponse.FromString,
                _registered_method=True)
        self.get_display_tiles = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_display_tiles',
                request_serializer=data__search__pb2.DataSearchDisplayTilesBatchGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchDisplayTilesBatchGetResponse.FromString,
                _registered_method=True)
        self.get_resource_batch = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_resource_batch',
                request_serializer=data__search__pb2.DataSearchResourceBatchGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchResourceBatchGetResponse.FromString,
                _registered_method=True)
        self.get_estimated_summary = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_estimated_summary',
                request_serializer=data__search__pb2.DataSearchEstimatedSummaryGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchEstimatedSummaryGetResponse.FromString,
                _registered_method=True)
        self.get_download_link = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_download_link',
                request_serializer=data__search__pb2.DataSourceGetDownloadLinkRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSourceGetDownloadLinkResponse.FromString,
                _registered_method=True)


class DataSearchApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_schema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_display_tiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_resource_batch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_estimated_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_download_link(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSearchApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_schema': grpc.unary_unary_rpc_method_handler(
                    servicer.get_schema,
                    request_deserializer=data__search__pb2.DataSearchSchemaGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchSchemaGetResponse.SerializeToString,
            ),
            'search': grpc.unary_unary_rpc_method_handler(
                    servicer.search,
                    request_deserializer=data__search__pb2.DataSearchRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchResponse.SerializeToString,
            ),
            'get_display_tiles': grpc.unary_unary_rpc_method_handler(
                    servicer.get_display_tiles,
                    request_deserializer=data__search__pb2.DataSearchDisplayTilesBatchGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchDisplayTilesBatchGetResponse.SerializeToString,
            ),
            'get_resource_batch': grpc.unary_unary_rpc_method_handler(
                    servicer.get_resource_batch,
                    request_deserializer=data__search__pb2.DataSearchResourceBatchGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchResourceBatchGetResponse.SerializeToString,
            ),
            'get_estimated_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.get_estimated_summary,
                    request_deserializer=data__search__pb2.DataSearchEstimatedSummaryGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchEstimatedSummaryGetResponse.SerializeToString,
            ),
            'get_download_link': grpc.unary_unary_rpc_method_handler(
                    servicer.get_download_link,
                    request_deserializer=data__search__pb2.DataSourceGetDownloadLinkRequest.FromString,
                    response_serializer=data__search__pb2.DataSourceGetDownloadLinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.DataSearchApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.DataSearchApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataSearchApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_schema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_schema',
            data__search__pb2.DataSearchSchemaGetRequest.SerializeToString,
            data__search__pb2.DataSearchSchemaGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/search',
            data__search__pb2.DataSearchRequest.SerializeToString,
            data__search__pb2.DataSearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_display_tiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_display_tiles',
            data__search__pb2.DataSearchDisplayTilesBatchGetRequest.SerializeToString,
            data__search__pb2.DataSearchDisplayTilesBatchGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_resource_batch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_resource_batch',
            data__search__pb2.DataSearchResourceBatchGetRequest.SerializeToString,
            data__search__pb2.DataSearchResourceBatchGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_estimated_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_estimated_summary',
            data__search__pb2.DataSearchEstimatedSummaryGetRequest.SerializeToString,
            data__search__pb2.DataSearchEstimatedSummaryGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_download_link(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_download_link',
            data__search__pb2.DataSourceGetDownloadLinkRequest.SerializeToString,
            data__search__pb2.DataSourceGetDownloadLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
