# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_analysis_config.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'project_analysis_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__version__pb2 = analysis__config__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = analysis__config__pb2.analysis_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__config__pb2 = analysis__config__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = analysis__config__pb2.algorithm_config_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__computation__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__computation__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_config_pb2 import *
from terrascope_api.models.analysis_computation_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *
from terrascope_api.models.result_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dproject_analysis_config.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x15\x61nalysis_config.proto\x1a\x1a\x61nalysis_computation.proto\x1a\x14\x61oi_collection.proto\x1a\x0cresult.proto\"U\n\"ProjectAnalysisConfigUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61nalysis_config_ids\x18\x02 \x03(\t\":\n#ProjectAnalysisConfigUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x7f\n\x18ProjectAnalysisConfigApi\x12\x63\n\x06update\x12+.oi.papi.ProjectAnalysisConfigUpdateRequest\x1a,.oi.papi.ProjectAnalysisConfigUpdateResponseP\x00P\x01P\x02P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_analysis_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTANALYSISCONFIGUPDATEREQUEST']._serialized_start=150
  _globals['_PROJECTANALYSISCONFIGUPDATEREQUEST']._serialized_end=235
  _globals['_PROJECTANALYSISCONFIGUPDATERESPONSE']._serialized_start=237
  _globals['_PROJECTANALYSISCONFIGUPDATERESPONSE']._serialized_end=295
  _globals['_PROJECTANALYSISCONFIGAPI']._serialized_start=297
  _globals['_PROJECTANALYSISCONFIGAPI']._serialized_end=424
# @@protoc_insertion_point(module_scope)
